==> deltaspike-1.9.6-source-release.zip: deltaspike-1.9.6/deltaspike/modules/data/impl/src/test/java/org/apache/deltaspike/data/test/domain/SimpleBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.data.test.domain;

import javax.persistence.EntityManager;

public class SimpleBuilder
{

    private final EntityManager entityManager;

    public SimpleBuilder(EntityManager entityManager)
    {
        this.entityManager = entityManager;
    }

    public Simple createSimple(String name, Integer counter)
    {
        Simple result = new Simple(name);
        result.setCounter(counter);
        return persistSimple(result);
    }

    public Simple createSimple(String name)
    {
        Simple result = new Simple(name);
        return persistSimple(result);
    }

    public Simple persistSimple(Simple result)
    {
        entityManager.persist(result);
        entityManager.flush();
        return result;
    }

}

==> deltaspike-2.0.1-source-release.zip: deltaspike-2.0.1/deltaspike/modules/data/impl/src/test/java/org/apache/deltaspike/data/test/domain/SimpleBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.deltaspike.data.test.domain;

import jakarta.persistence.EntityManager;

public class SimpleBuilder
{

    private final EntityManager entityManager;

    public SimpleBuilder(EntityManager entityManager)
    {
        this.entityManager = entityManager;
    }

    public Simple createSimple(String name, Integer counter)
    {
        Simple result = new Simple(name);
        result.setCounter(counter);
        return persistSimple(result);
    }

    public Simple createSimple(String name)
    {
        Simple result = new Simple(name);
        return persistSimple(result);
    }

    public Simple persistSimple(Simple result)
    {
        entityManager.persist(result);
        entityManager.flush();
        return result;
    }

}
